# Generated by Django 2.2.3 on 2019-12-03 17:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("response", "0015_improve_actions")]

    operations = [
        migrations.AlterField(
            model_name="action",
            name="created_date",
            field=models.DateTimeField(auto_now_add=True, null=True),
        )
    ]



import bleach
import bleach_whitelist
from django.conf import settings
from rest_framework.pagination import PageNumberPagination


def sanitize(string):
    # bleach doesn't handle None so let's not pass it
    if string and getattr(settings, "RESPONSE_SANITIZE_USER_INPUT", True):
        return bleach.clean(
            string,
            tags=bleach_whitelist.markdown_tags,
            attributes=bleach_whitelist.markdown_attrs,
            styles=bleach_whitelist.all_styles,
        )

    return string


class LargeResultsSetPagination(PageNumberPagination):
    page_size = 500
    max_page_size = 1000
    page_size_query_param = "page_size"



# Generated by Django 2.2.3 on 2019-11-28 16:52

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("response", "0014_event")]

    operations = [
        migrations.AddField(
            model_name="action",
            name="created_date",
            field=models.DateTimeField(null=True),
        ),
        migrations.AddField(
            model_name="action", name="done_date", field=models.DateTimeField(null=True)
        ),
        migrations.AddField(
            model_name="action", name="due_date", field=models.DateTimeField(null=True)
        ),
        migrations.AddField(
            model_name="action",
            name="priority",
            field=models.CharField(
                blank=True,
                choices=[("1", "high"), ("2", "medium"), ("3", "low")],
                max_length=10,
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="action",
            name="type",
            field=models.CharField(
                blank=True,
                choices=[
                    ("1", "detective"),
                    ("2", "preventative"),
                    ("3", "corrective"),
                ],
                max_length=10,
                null=True,
            ),
        ),
    ]
